@@ -1,5 +1,9 @@
 #define QT_FEATURE_ffmpeg 1
 
+#define QT_FEATURE_pipewire -1
+
+#define QT_FEATURE_pipewire_screencapture -1
+
 #define QT_FEATURE_alsa -1
 
 #define QT_FEATURE_avfoundation -1
@@ -8,17 +12,17 @@
 
 #define QT_FEATURE_videotoolbox -1
 
-#define QT_FEATURE_evr 1
-
-#define QT_FEATURE_gstreamer_1_0 -1
-
-#define QT_FEATURE_gstreamer_app -1
+#define QT_FEATURE_gstreamer -1
 
 #define QT_FEATURE_gstreamer_photography -1
 
 #define QT_FEATURE_gstreamer_gl -1
 
-#define QT_FEATURE_gstreamer -1
+#define QT_FEATURE_gstreamer_gl_wayland -1
+
+#define QT_FEATURE_gstreamer_gl_egl -1
+
+#define QT_FEATURE_gstreamer_gl_x11 -1
 
 #define QT_FEATURE_gpu_vivante -1
 
@@ -30,6 +34,8 @@
 
 #define QT_FEATURE_mmrenderer -1
 
+#define QT_FEATURE_native_android_backend -1
+
 #define QT_FEATURE_pulseaudio -1
 
 #define QT_FEATURE_wmsdk 1
